==> tuia-advert-center-api-1.5.9-20180813.072955-39-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AppAdvertWhiteApplyDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.util.Date;

public class AppAdvertWhiteApplyDto {
    private Long id;

    private Long appId;

    private String slotIds;

    private Integer applyStatus;

    private String refuseReason;

    private String strategyTypes;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getSlotIds() {
        return slotIds;
    }

    public void setSlotIds(String slotIds) {
        this.slotIds = slotIds == null ? null : slotIds.trim();
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason == null ? null : refuseReason.trim();
    }

    public String getStrategyTypes() {
        return strategyTypes;
    }

    public void setStrategyTypes(String strategyTypes) {
        this.strategyTypes = strategyTypes == null ? null : strategyTypes.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-advert-center-api-2.2.72-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AppAdvertWhiteApplyDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;
import java.util.Date;

public class AppAdvertWhiteApplyDto  implements Serializable {
    private static final long serialVersionUID = -2842774512901201993L;
    private Long id;

    private Long appId;

    private String slotIds;

    private Integer applyStatus;

    private String refuseReason;

    private String strategyTypes;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getSlotIds() {
        return slotIds;
    }

    public void setSlotIds(String slotIds) {
        this.slotIds = slotIds == null ? null : slotIds.trim();
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason == null ? null : refuseReason.trim();
    }

    public String getStrategyTypes() {
        return strategyTypes;
    }

    public void setStrategyTypes(String strategyTypes) {
        this.strategyTypes = strategyTypes == null ? null : strategyTypes.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
